@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light::Timeout::Alarm;
 {
-    $Riak::Light::Timeout::Alarm::VERSION = '0.056';
+    $Riak::Light::Timeout::Alarm::VERSION = '0.057';
 }
 ## use critic
 
@@ -18,7 +18,7 @@ use Time::HiRes qw(alarm);
 use Riak::Light::Util qw(is_windows);
 use Carp;
 use Moo;
-use MooX::Types::MooseLike::Base qw<Num Str Int Bool Object>;
+use Types::Standard -types;
 with 'Riak::Light::Timeout';
 
 # ABSTRACT: proxy to read/write using Alarm as a timeout provider ( Not Safe: can clobber previous alarm )
@@ -43,25 +43,15 @@ sub BUILD {
 }
 
 sub clean {
-    my $self = shift;
-    $self->socket->close;
-    $self->is_valid(0);
+    $_[0]->socket->close;
+    $_[0]->is_valid(0);
 }
 
-around [qw(sysread syswrite)] => sub {
-    my $orig = shift;
-    my $self = shift;
-
-    if ( !$self->is_valid ) {
-        $! = ECONNRESET;    ## no critic (RequireLocalizedPunctuationVars)
-        return;
-    }
-
-    $self->$orig(@_);
-};
-
 sub sysread {
     my $self = shift;
+    $self->is_valid
+      or $! = ECONNRESET,
+      return;    ## no critic (RequireLocalizedPunctuationVars)
 
     my $buffer;
     my $seconds = $self->in_timeout;
@@ -90,6 +80,9 @@ sub sysread {
 
 sub syswrite {
     my $self = shift;
+    $self->is_valid
+      or $! = ECONNRESET,
+      return;    ## no critic (RequireLocalizedPunctuationVars)
 
     my $seconds = $self->out_timeout;
     my $result  = eval {
@@ -121,7 +114,7 @@ Riak::Light::Timeout::Alarm - proxy to read/write using Alarm as a timeout provi
 
 =head1 VERSION
 
-version 0.056
+version 0.057
 
 =head1 DESCRIPTION
 
