@@ -9,7 +9,7 @@
 ## no critic (RequireUseStrict, RequireUseWarnings)
 package Riak::Light::Timeout::TimeOut;
 {
-    $Riak::Light::Timeout::TimeOut::VERSION = '0.056';
+    $Riak::Light::Timeout::TimeOut::VERSION = '0.057';
 }
 ## use critic
 
@@ -19,7 +19,7 @@ use Time::HiRes;
 use Riak::Light::Util qw(is_windows);
 use Carp;
 use Moo;
-use MooX::Types::MooseLike::Base qw<Num Str Int Bool Object>;
+use Types::Standard -types;
 
 with 'Riak::Light::Timeout';
 
@@ -42,25 +42,15 @@ sub BUILD {
 }
 
 sub clean {
-    my $self = shift;
-    $self->socket->close;
-    $self->is_valid(0);
+    $_[0]->socket->close;
+    $_[0]->is_valid(0);
 }
 
-around [qw(sysread syswrite)] => sub {
-    my $orig = shift;
-    my $self = shift;
-
-    if ( !$self->is_valid ) {
-        $! = ECONNRESET;    ## no critic (RequireLocalizedPunctuationVars)
-        return;
-    }
-
-    $self->$orig(@_);
-};
-
 sub sysread {
     my $self = shift;
+    $self->is_valid
+      or $! = ECONNRESET,
+      return;    ## no critic (RequireLocalizedPunctuationVars)
 
     my $buffer;
     my $seconds = $self->in_timeout;
@@ -82,6 +72,9 @@ sub sysread {
 
 sub syswrite {
     my $self = shift;
+    $self->is_valid
+      or $! = ECONNRESET,
+      return;    ## no critic (RequireLocalizedPunctuationVars)
 
     my $seconds = $self->out_timeout;
     my $result = timeout $seconds, @_ => sub {
@@ -106,7 +99,7 @@ Riak::Light::Timeout::TimeOut - proxy to read/write using Time::Out as a timeout
 
 =head1 VERSION
 
-version 0.056
+version 0.057
 
 =head1 DESCRIPTION
 
